// THIS CODE AND INFORMATION ARE PROVIDED "AS IS" WITHOUT WARRANTY OF ANY KIND, EITHER EXPRESSED OR IMPLIED!
// YOU MAY USE THIS CODE: HOWEVER THIS GRANTS NO FUTURE RIGHTS.
// see http://telnetcsharp.codeplex.com/ for further details and license information

using System;
using System.Text;

namespace TelnetCSharp.Demo
{
	/// <summary>
	/// Some Test methods for the screen class
	/// </summary>
	public class VirtualScreenTest
	{
		/// <summary>
		/// The main entry point for the application.
		/// Can be used to test the programm and run it from command line.
		/// </summary>
		/// <param name="args"></param>
		// ReSharper disable UnusedMember.Local
		// ReSharper disable UnusedParameter.Local
		[STAThread]
		private static void Main(string[] args)
		{
			const string screenEnd = "--- screen ends here ---";
			// coordinates are 0,0 based since we do not specify anything
			var vs = new VirtualScreen(80, 40);
			// simple fill
			FillScreen(vs);
			Console.WriteLine(vs.Hardcopy());
			Console.WriteLine(screenEnd);
			Console.ReadLine();
			// deleting of an area
			vs.CleanScreen(4, 4, 75, 35);
			Console.WriteLine(vs.Hardcopy());
			Console.WriteLine(screenEnd);
			Console.ReadLine();
			// scrolling
			vs.ScrollUp(2);
			Console.WriteLine(vs.Hardcopy());
			Console.WriteLine(screenEnd);
			Console.ReadLine();
			// block operations (write to screen)
			WriteBlockOperation(vs);
			Console.WriteLine(vs.Hardcopy());
			Console.WriteLine(screenEnd);
			Console.ReadLine();
			// cursor movements
			WriteBigX(vs);
			Console.WriteLine(vs.Hardcopy());
			Console.WriteLine(screenEnd);
			Console.ReadLine();
		}

		// ReSharper restore UnusedParameter.Local
		// ReSharper restore UnusedMember.Local

		/// <summary>
		/// Fill the screen with a pattern
		/// </summary>
		/// <param name="vs">Virtual screen</param>
		public static void FillScreen(VirtualScreen vs)
		{
			for (int y = 0; y < vs.Height; y++)
			{
				byte w = 48; // 48=0 57=9
				for (int x = 0; x < vs.Width; x++)
				{
					vs.WriteByte(w);
					if (w < 57)
						w++;
					else
						w = 48;
				}
			}
		}

		/// <summary>
		/// Write a byte block and strings
		/// </summary>
		/// <param name="vs">Virtual screen</param>
		public static void WriteBlockOperation(VirtualScreen vs)
		{
			vs.CleanScreen();
			byte[] tb = Encoding.ASCII.GetBytes("This is a test output");
			vs.WriteLine("New screen with test output:");
			for (int i = 0; i < 10; i++)
			{
				vs.WriteByte(tb);
			}
			vs.WriteLine("\n");
			for (int i = 0; i < 10; i++)
			{
				vs.WriteLine("Line output");
			}
		}

		/// <summary>
		/// Test cursor movements
		/// </summary>
		/// <param name="vs">Virtual screen</param>
		public static void WriteBigX(VirtualScreen vs)
		{
			vs.CleanScreen();
			for (int i = 0; i < vs.Height; i++)
			{
				vs.Write('X'); // already moves cursor about one
				vs.MoveCursor(vs.Width); // test overflow
			}
			vs.Write('\r'); // beginning of last line
			for (int i = 0; i < vs.Height; i++)
			{
				vs.Write('X'); // already moves cursor about one
				vs.MoveCursor(-vs.Width); // test overflow
			}
		}
	} // class
}

// namespace